# libalgebra_tests

A testing suite for the [libalgebra](https://github.com/terrylyons/libalgebra) C++ library.

### Build tests

```
docker build -t libalgebra_tests .
```

### Run tests

```
docker run -it libalgebra_tests
```
